@@ -45,48 +45,27 @@ class EventBus:
             pass
 
 
+
 class WebSocketBot:
-    def __init__(self, uri: str,blocked_loggers=None,all_str_id=False):
+    def __init__(self, uri: str,blocked_loggers=None):
         self.uri = uri
         self.websocket: Optional[websockets.WebSocketClientProtocol] = None
-        self.logger = get_logger(blocked_loggers)
+        self.logger = get_logger(blocked_loggers=blocked_loggers)
         self.event_bus = EventBus()
         self.response_callbacks: Dict[str, asyncio.Future] = {}
         self.receive_task: Optional[asyncio.Task] = None
-        self.all_str_id=all_str_id
 
+        self._message_queue = asyncio.Queue()  # 添加消息队列
+        self._processing_task: Optional[asyncio.Task] = None  # 添加处理任务
 
     async def _receive(self):
         """
-        接收服务端消息并分发处理。
+        接收服务端消息并放入队列。
         """
         try:
             async for response in self.websocket:
-                data = json.loads(response)
-                self.logger.info_msg(f"收到服务端响应: {data}")
-
-                # 如果是响应消息
-                if "status" in data and "echo" in data:
-                    echo = data["echo"]
-                    future = self.response_callbacks.pop(echo, None)
-                    if future and not future.done():
-                        future.set_result(data)
-                elif "post_type" in data:
-                    event_obj = EventFactory.create_event(data)
-                    try:
-                        if event_obj.post_type=="meta_event":
-
-                            if event_obj.meta_event_type=="lifecycle":
-                                self.id = int(event_obj.self_id)
-                                self.logger.info_msg(f"Bot ID: {self.id}")
-                    except:
-                        pass
-                    if event_obj:
-                        asyncio.create_task(self.event_bus.emit(event_obj))  #不能await，否则会阻塞
-                    else:
-                        self.logger.warning("无法匹配事件类型，跳过处理。")
-                else:
-                    self.logger.warning("收到未知消息格式，已忽略。")
+                # 将消息放入队列而不是直接处理
+                await self._message_queue.put(response)
         except websockets.exceptions.ConnectionClosedError as e:
             self.logger.warning(f"WebSocket 连接关闭: {e}")
             self.logger.warning("5秒后尝试重连")
@@ -102,6 +81,54 @@ class WebSocketBot:
             self.response_callbacks.clear()
             self.receive_task = None
 
+    async def _process_messages(self):
+        """
+        从队列中处理消息。
+        """
+        try:
+            while True:
+                try:
+                    # 从队列中获取消息
+                    response = await self._message_queue.get()
+                    data = json.loads(response)
+                    self.logger.info_msg(f"收到服务端响应: {data}")
+
+                    # 如果是响应消息
+                    if "status" in data and "echo" in data:
+                        echo = data["echo"]
+                        future = self.response_callbacks.pop(echo, None)
+                        if future and not future.done():
+                            future.set_result(data)
+                    elif "post_type" in data:
+                        event_obj = EventFactory.create_event(data)
+                        try:
+                            if event_obj.post_type == "meta_event":
+                                if event_obj.meta_event_type == "lifecycle":
+                                    self.id = int(event_obj.self_id)
+                                    self.logger.info_msg(f"Bot ID: {self.id}")
+                        except:
+                            pass
+                        if event_obj:
+                            # 创建独立任务处理事件，避免阻塞消息处理
+                            asyncio.create_task(self.event_bus.emit(event_obj))
+                        else:
+                            self.logger.warning("无法匹配事件类型，跳过处理。")
+                    else:
+                        self.logger.warning("收到未知消息格式，已忽略。")
+
+                    # 标记任务完成
+                    self._message_queue.task_done()
+
+                except asyncio.CancelledError:
+                    break
+                except Exception as e:
+                    self.logger.error(f"处理消息时发生错误: {e}", exc_info=True)
+
+        except asyncio.CancelledError:
+            pass
+        finally:
+            self._processing_task = None
+
     async def _connect_and_run(self):
         """
         建立 WebSocket 连接并开始接收消息。
